==> haskell-gnuidn-0.2.2-21-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-gnuidn.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: gnuidn
version: 0.2.2
id: gnuidn-0.2.2-3Asbckfml6kC0QtQ3vZ80Y
key: gnuidn-0.2.2-3Asbckfml6kC0QtQ3vZ80Y
license: GPL-3
maintainer: jmillikin@gmail.com
stability: experimental
homepage: https://john-millikin.com/software/haskell-gnuidn/
synopsis: Bindings for GNU IDN
category: Codec, Text
author: John Millikin
exposed: True
indefinite: False
exposed-modules:
    Data.Text.IDN.IDNA Data.Text.IDN.Punycode Data.Text.IDN.StringPrep
hidden-modules: Data.Text.IDN.Internal
abi: b5baca0abaafa7ad14bd75e1cf057349
trusted: False
import-dirs: /usr/lib/ghc-8.2.2/site-local/gnuidn-0.2.2
library-dirs: /usr/lib/ghc-8.2.2/site-local/gnuidn-0.2.2
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.2.2/gnuidn-0.2.2
hs-libraries: HSgnuidn-0.2.2-3Asbckfml6kC0QtQ3vZ80Y
extra-libraries:
    idn idn
depends:
    base-4.10.1.0 text-1.2.3.0-FxgEmn4RjqC37dwdnPGDhj
    bytestring-0.10.8.2
abi-depends: base-4.10.1.0=35a7f6be752ee4f7385cb5bf28677879
             text-1.2.3.0-FxgEmn4RjqC37dwdnPGDhj=d51c5ac73448d7d6c9cbe4dedb95457e
             bytestring-0.10.8.2=4a9e2cf748f0e2cc5be33be7a5505ecf
haddock-interfaces: /usr/share/doc/haskell-gnuidn/html/gnuidn.haddock
haddock-html: /usr/share/doc/haskell-gnuidn/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-gnuidn-0.2.2-73-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-gnuidn.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: gnuidn
version: 0.2.2
id: gnuidn-0.2.2-IWI1OHDbzQ6C9U3q4GXFKa
key: gnuidn-0.2.2-IWI1OHDbzQ6C9U3q4GXFKa
license: GPL-3.0-only
maintainer: jmillikin@gmail.com
author: John Millikin
stability: experimental
homepage: https://john-millikin.com/software/haskell-gnuidn/
synopsis: Bindings for GNU IDN
category: Codec, Text
abi: 6e9db4de4081d8ff130d93c111f33e15
exposed: True
exposed-modules:
    Data.Text.IDN.IDNA Data.Text.IDN.Punycode Data.Text.IDN.StringPrep
hidden-modules: Data.Text.IDN.Internal
import-dirs: /usr/lib/ghc-8.4.3/site-local/gnuidn-0.2.2
library-dirs: /usr/lib/ghc-8.4.3/site-local/gnuidn-0.2.2
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.4.3/gnuidn-0.2.2
hs-libraries: HSgnuidn-0.2.2-IWI1OHDbzQ6C9U3q4GXFKa
extra-libraries:
    idn idn
depends:
    base-4.11.1.0 text-1.2.3.0 bytestring-0.10.8.2
abi-depends: base-4.11.1.0=9da3f387598d41928f3ebf8097acf9b3
             text-1.2.3.0=be4c3e1c57cff1d501eb0e876706a48d
             bytestring-0.10.8.2=76943c00398d547fb172e56c2f93c635
haddock-interfaces: /usr/share/doc/haskell-gnuidn/html/gnuidn.haddock
haddock-html: /usr/share/doc/haskell-gnuidn/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
